Welcome to the Brutal Maze wiki!

* [Installation](https://github.com/McSinyx/brutalmaze/wiki/Installation)
* [Configuration](https://github.com/McSinyx/brutalmaze/wiki/Configuration)
* [Gameplay](https://github.com/McSinyx/brutalmaze/wiki/Gameplay)
* [Remote control](https://github.com/McSinyx/brutalmaze/wiki/Remote-control)
* [Credits](https://github.com/McSinyx/brutalmaze/wiki/Credits)
